@@ -125,10 +125,15 @@ def get_length(arg):
             total_length += 2 + len(op[0]) + get_length(op[1])
         total_length += get_length(arg.left)
         return total_length
-    if isinstance(arg, astroid.nodes.List) or isinstance(arg, astroid.nodes.Subscript):
+    if isinstance(arg, astroid.nodes.List):
         total_length = 0
         for value in arg.elts:
             total_length += get_length(value)
         return total_length
+    if isinstance(arg, astroid.nodes.Subscript):
+        print(arg.lineno)
+        total_length = 0
+        total_length += get_length(arg.value)
+        return total_length
     print(f"Unhandled {arg}")
     return 0
